GooglePrivacyDlpV2beta1CharacterMaskConfig

Struct GooglePrivacyDlpV2beta1CharacterMaskConfig 

pub struct GooglePrivacyDlpV2beta1CharacterMaskConfig {
    pub characters_to_ignore: Option<Vec<GooglePrivacyDlpV2beta1CharsToIgnore>>,
    pub masking_character: Option<String>,
    pub reverse_order: Option<bool>,
    pub number_to_mask: Option<i32>,
}
Partially mask a string by replacing a given number of characters with a fixed character. Masking can start from the beginning or end of the string. This can be used on data of any type (numbers, longs, and so on) and when de-identifying structured data we’ll attempt to preserve the original data’s type. (This allows you to take a long like 123 and modify it to a string like **3.

This type is not used in any activity, and only used as part of another schema.

Fields

characters_to_ignore: Option<Vec<GooglePrivacyDlpV2beta1CharsToIgnore>>

When masking a string, items in this list will be skipped when replacing. For example, if your string is 555-555-5555 and you ask us to skip - and mask 5 chars with * we would produce ***-*55-5555.

masking_character: Option<String>

Character to mask the sensitive values—for example, “” for an alphabetic string such as name, or “0” for a numeric string such as ZIP code or credit card number. String must have length 1. If not supplied, we will default to “” for strings, 0 for digits.

reverse_order: Option<bool>

Mask characters in reverse order. For example, if masking_character is ‘0’, number_to_mask is 14, and reverse_order is false, then 1234-5678-9012-3456 -> 00000000000000-3456 If masking_character is ‘’, number_to_mask is 3, and reverse_order is true, then 12345 -> 12**

number_to_mask: Option<i32>

Number of characters to mask. If not set, all matching chars will be masked. Skipped characters do not count towards this tally.