pub struct GooglePrivacyDlpV2beta1Color {
pub red: Option<f32>,
pub green: Option<f32>,
pub blue: Option<f32>,
}Expand description
Represents a color in the RGB color space.
This type is not used in any activity, and only used as part of another schema.
Fields
red: Option<f32>The amount of red in the color as a value in the interval [0, 1].
green: Option<f32>The amount of green in the color as a value in the interval [0, 1].
blue: Option<f32>The amount of blue in the color as a value in the interval [0, 1].